@@ -1,19 +1,24 @@
-__version__ = '0.1.0'
+__version__ = '0.2.0'
 
 import requests
 import json
 import sseclient
 
 class StreamBot:
-    def __init__(self, api_key, bot_name, openai_url = 'https://api.openai.com/v1/chat/completions'):
+    def __init__(self, api_key, bot_name, genesis_prompt, openai_url = 'https://api.openai.com/v1/chat/completions'):
         self.api_key = api_key
         self.bot_name = bot_name
+        self.genesis_prompt = genesis_prompt
+        self.messages = [{"role":"system", "content": genesis_prompt}]
         self.openai_url = openai_url
 
-    def chat(self, messages):
+    def add_message(self, message, role="user"):
+      self.messages.append({"role": role, "content": message})
+
+    def chat(self):
         reqBody = {
           "model": "gpt-3.5-turbo-0301",
-          "messages": messages,
+          "messages": self.messages,
           "stream": True
       }
         reqHeaders = {
@@ -41,5 +46,9 @@ class StreamBot:
                     pass
         except requests.exceptions.RequestException as e:
             print(f"An error occurred: {e}")
-          
-        return "".join(response_text)
+        
+        result = "".join(response_text)
+      
+        self.add_message(result, role="assistant")
+        
+        return result
